// Class: DisplayableTable
//
// Author: Alyce Brady and Kelly Schultz
// Date:  Spring 2004
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.TextCell;
import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.TextCellDisplay;
import edu.kzoo.grid.gui.GridAppFrame;

import java.awt.Color;

/**
 *   DisplayableTable Class:<br>
 *
 *    The DisplayableTable class constructs a table of grid cells.  
 *    Created for use in a histogram project.
 *
 *  @author Alyce Brady
 *  @author Kelly Schultz
 *  @version 25 March 2004
 **/
public class DisplayableTable extends GridAppFrame
{
    // Specify dimensions of grid display and individual cell size.
    private static final int MAX_WIDTH = 800;
    private static final int MAX_HEIGHT = 600;
    private static final int MIN_CELL_SIZE = 10;

    // Specify the grid's background color and highlight color.
    private static final Color BACKGROUND_COLOR = new Color(0, 155, 255);
    private static final Color HIGHLIGHT_COLOR = Color.red;


    /**
     *  Constructs a table of cells accessible by row and column.
     *  (Precondition: <code>numValues < 20</code>.)
     *  @param title     title for top of window displaying table
     *  @param numValues the number of values to plot
     *  @param maxValue  the maximum value that could be plotted;
     *                   the table is scaled so that a full row
     *                   represents this value
     **/
    public DisplayableTable(String title, int numValues, int maxValue)
    {
    	super();
		constructWindowContents(title, BACKGROUND_COLOR, 
                                MAX_HEIGHT, MAX_WIDTH, MIN_CELL_SIZE);

        // Construct a grid in which to draw the table.
        setGrid(new BoundedGrid(numValues, maxValue));
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());
        DisplayMap.associate("edu.kzoo.grid.TextCell", new TextCellDisplay());
    }

 
    /** Adds a color block in the table.
     *  (Precondition: <code>0 <= row < numValues</code> and 
     *   <code>0 <= value <= maxValue</code>, where <code>numValues</code>
     *   and <code>maxValue</code> are the values specified when the table
     *   was constructed.)
     *  @param row the row in which a value is to be plotted
     *  @param value the value to be plotted
     **/
    public void add(Color blockColor, int row, int col)
    {
    	//  Add a new Color Block to the table at the row and column specified.
        getGrid().add(new ColorBlock(blockColor), new Location(row, col));
        
    }

    /** Adds a text block  in the table.
     *  (Precondition: <code>0 <= row < numValues</code> and 
     *   <code>0 <= value <= maxValue</code>, where <code>numValues</code>
     *   and <code>maxValue</code> are the values specified when the table
     *   was constructed.  Also, <code>label</code> is a short enough string
     *   to be displayed in a single cell in the table grid.)
     *  @param label  the label for the row
     *  @param row the row in which a value is to be plotted
     *  @param value the value to be plotted
     **/
    public void add(String label, int row, int col)
    {
        // Add a new text cell to the table at the given location.
        getGrid().add(new TextCell(label), new Location(row, col));
    }

    /** Displays the table.
     **/
    public void display()
    {
        showGrid();
    }

}
